writePhylip

Writes a PHYLIP-formatted file of fully concatenated gene datasets and an associated partition file for RAxML concatenated phylogenetic analysis
catGenes::writePhylip()

Description

From the resulting list of equally-sized dataframes containing the input individual DNA alignments, as generated by the functions catfullGenes or catmultGenes, it will write (i) a final PHYLIP-formatted file of fully concatenated dataset and (ii) an associated partition file for the RAxML concatenated phylogenetic analysis using a mixed/partitioned model.

Arguments

Argument Description
x The object to be written, a list of equally-sized dataframes containing the input gene datasets, as generated by the functions or catmultGenes.
file Either a character string naming a file or a connection open for writing.
genomics Logical, if TRUE, it will be helpful in phylogenomics where all provided species identifiers (e.g. collector number and GenBank accession numbers) will always be kept in the resultant concatenated dataset.
catalignments Logical, if FALSE will not write the concatenated matrix of DNA alignments. Better to keep it always as TRUE.
partitionfile Logical, if FALSE will not write the associated text-formatted partition file for the RAxML concatenated phylogenetic analysis using a mixed/partitioned model.
endgaps.to.miss Logical, if FALSE the function will not replace terminal GAPs into missing character (?).

Examples

data(Gaya)
df <- catfullGenes(Gaya,
                   shortaxlabel = TRUE,
                   missdata = FALSE,
                   outgroup = "Abutilon_costicalyx")

writePhylip(df,
            file = "filename.phy",
            genomics = FALSE,
            catalignments = TRUE,
            partitionfile = TRUE,
            verbose = TRUE)