catGenes::catfullGenes()catfullGenes
Compares gene datasets for combined phylogenetic analysis
Description
Compares a list of “n” gene datasets (individual DNA alignments) and makes them with the same number of taxa, ready for combined, multigene phylogenetic analysis. This function only works for DNA alignments where species do not have duplicated sequences. For concatenation when species have multiple accessions, please use catmultGenes.
Arguments
| Argument | Description |
|---|---|
| … | a list of NEXUS-formatted gene datasets as read by ape’s read.nexus.data or at least two individually ape-read objects of NEXUS-formatted gene datasets. |
| shortaxlabel | Logical, if FALSE the final individual gene dataset will maintain the accession numbers associated with each species or sequence. |
| missdata | Logical, if FALSE the comparison will exclude any species that lacks a complete sequence for one of the input gene dataset. |
| outgroup | Provide the outgroup taxa (either one taxon name or a vector of multiple taxon names that are present in all individual gene dataset) if the concatenation is intended to maintain incomplete taxa (taxa missing the sequence for a particular gene). |
| verbose | Logical, if FALSE, a message showing each step during gene matching search will not be printed in the console in full. |
Value
A list of dataframes of the equally-sized gene dataset, where the first column “species” include all taxon names and the second column “sequence” include the DNA sequence for the corresponding taxon.
Examples
data(Gaya)
catdf <- catfullGenes(Gaya,
shortaxlabel = TRUE,
missdata = FALSE,
outgroup = "Abutilon_costicalyx",
verbose = TRUE)
outgrouptaxa <- c("Abutilon_costicalyx", "Abutilon_itatiaie")
catdf <- catfullGenes(Gaya,
shortaxlabel = TRUE,
missdata = FALSE,
outgroup = outgrouptaxa,
verbose = TRUE)