catGenes::run_catGenes()run_catGenes
Run catGenes under a Shiny Application
Description
This function runs the catGenes application. It will open the application by using the default internet browser, or the viewer if running from RStudio.
Arguments
| Argument | Description |
|---|---|
| launch.browser | Run catGenes in browser |
| port | If launch.browser is FALSE, specify port to run catGenes |
Examples
if (interactive()) {
run_catGenes()
}